@@ -102,8 +102,8 @@ function(x,col,col.line,lwd,main,xlab,ylab,...)
   if(DB==FALSE)
   {
    legend("topright",legend=c(c(expression(bold("Type I error:")),x$sig.level,
-          expression(bold("Type II error:")),paste(round(1-x$power,7),"(", round(1-x$power,2),"%)"),
-          expression(bold("Power:")),paste(round(x$power,7),"(", round(x$power,2),"%)"))),
+          expression(bold("Type II error:")),paste(round(1-x$power,6),"(", round(1-x$power,4)*100,"%)"),
+          expression(bold("Power:")),paste(round(x$power,6),"(", round(x$power,4)*100,"%)"))),
           fill=c(col[1],0,col[2],0,col[3],0),y.intersp=1,inset=0.04,border=c(1,0,1,0,1,0))
   }
  invisible()
